<?php

/*
Plugin Name: eesy Posttype
Plugin URI: https://eesy.com
Description: eesy Posttype gives you the opportunity to easily add Custom Post Types and related taxonomies – just the eesy way.
Version: 1.0.4
Author: INCREON Digital Lab GmbH
Author URI: https://increon-digitallab.com
License: GNU GPL3
Text Domain: eesy-posttype
Domain Path: /languages
*/

define('EESY_POST_TYPE_VERSION', '1.0');
define('EESY_POST_TYPE_PLUGIN_URL', plugin_dir_url(__FILE__));
define('EESY_POST_TYPE_PLUGIN_PIC_URL', plugin_dir_url(__FILE__) . "images/");
define('EESY_POST_TYPE_PLUGIN_DIR', plugin_dir_path(__FILE__));
define('EESY_POST_TYPE_PLUGIN_FRONTEND_TEMPLATE_DIR', plugin_dir_path(__FILE__) . 'frontend/tpl/');


// plugin installation / deinstallation START
function eesy_posttype_activate() {
    if (!get_option('eesy_post_types')) {
        update_option('eesy_post_types', '');
    }
    if (!get_option('eesy_custom_taxonomies')) {

        update_option('eesy_custom_taxonomies', '');
    }
    if (!get_option('eesy_plugin_options')) {
        update_option('eesy_plugin_options', '');
    }

    flush_rewrite_rules();
}

function eesy_posttype_uninstall() {
    $options = unserialize(get_option('eesy_plugin_options'));
    if ($options['eesy-posttype_attributes-delete-all-content'] == 'true') {
        eesy_posttype_all_delete();

        delete_option('eesy_post_types');
        delete_option('eesy_custom_taxonomies');
        delete_option('eesy_plugin_options');
    }
}

function eesy_posttype_all_delete() {
    $eesy_custom_post_types = unserialize(get_option('eesy_post_types'));
    $eesy_custom_taxonomies = unserialize(get_option('eesy_custom_taxonomies'));
    foreach ($eesy_custom_post_types as $key => $value) {
        eesy_posttype_delete_posts($value['eesy_post_type_name']);
    }

    foreach ($eesy_custom_taxonomies as $key => $value) {
        $terms = get_terms(array(
            'taxonomy' => strtolower($value['taxlabel']['eesy-posttype_taxonomies-name']),
            'hide_empty' => false,
        ));
        foreach ($terms as $key_terms => $value_terms) {
            wp_delete_term($value_terms->term_id, strtolower($value['taxlabel']['eesy-posttype_taxonomies-name']));
        }
    }
}

register_activation_hook(__FILE__, 'eesy_posttype_activate');
register_uninstall_hook(__FILE__, 'eesy_posttype_uninstall');
// plugin installation / deinstallation END


// load language files START
function load_eesy_posttype_plugin_languagefiles() {
    load_plugin_textdomain('eesy-posttype', false, 'eesy-posttype/languages');
}

add_action('init', 'load_eesy_posttype_plugin_languagefiles');
// load language files END


// integrate eesy plugins admin stylesheets and JS scripts START
function load_eesy_post_plugin_admin_style($hook) {
    // Load only on ?page=mypluginname
    if ($hook != 'toplevel_page_eesy_posttype' && $hook != 'eesy-posttype_page_eesy_posttype_posttypes' && $hook != 'eesy-posttype_page_eesy_posttype_taxonomies' && $hook != 'eesy-posttype_page_eesy_posttype_options' && $hook != 'eesy-posttype_page_eesy_posttype_faq') {
        return;
    }
    wp_enqueue_style('eesy-posttype-css', plugins_url('css/eesy_plugins_admin.css', __FILE__));
    wp_enqueue_style('eesy-plugins-font', 'https://fonts.googleapis.com/css?family=Roboto+Condensed:300,700', __FILE__, false, false);
    wp_enqueue_script('eesy-plugins-admin-js', plugins_url('js/eesy_plugins_admin.js', __FILE__, array('jquery'), false, false));
    wp_enqueue_script('eesy-posttype-js', plugins_url('js/eesy_posttype.js', __FILE__, array('jquery'), false, false));
}

add_action('admin_enqueue_scripts', 'load_eesy_post_plugin_admin_style');
// integrate eesy plugins admin stylesheets and JS scripts END


// integrate fontawesome 5 JS+SVG version START
if (!wp_script_is('fontawesome.js', 'enqueued')) {
    function eesy_posttype_load_font_awesome($hook) {
        if ($hook != 'toplevel_page_eesy_posttype' && $hook != 'eesy-posttype_page_eesy_posttype_posttypes' && $hook != 'eesy-posttype_page_eesy_posttype_taxonomies' && $hook != 'eesy-posttype_page_eesy_posttype_options' && $hook != 'eesy-posttype_page_eesy_posttype_faq') {
            return;
        }
        wp_enqueue_script('font-awesome-solid', 'https://use.fontawesome.com/releases/v5.1.0/js/solid.js', __FILE__, false, false);
        wp_enqueue_script('font-awesome-brands', 'https://use.fontawesome.com/releases/v5.1.0/js/brands.js', __FILE__, false, false);
        wp_enqueue_script('font-awesome', 'https://use.fontawesome.com/releases/v5.1.0/js/fontawesome.js', __FILE__, false, false);
    }

    add_action('admin_enqueue_scripts', 'eesy_posttype_load_font_awesome');
    add_filter('script_loader_tag', 'eesy_posttype_add_defer_attribute', 10, 2);

    function eesy_posttype_add_defer_attribute($tag, $handle) {
        if (( 'font-awesome-solid' === $handle ) or ( 'font-awesome-brands' === $handle ) or ( 'font-awesome' === $handle )) {
            $tag = str_replace(' src', ' defer src', $tag);
        }
        return $tag;
    }
}
// integrate fontawesome 5 JS+SVG version END


// add posttype to admin menu START
add_action('admin_menu', 'eesy_post_type_admin_menu');

function eesy_post_type_admin_menu() {

    $text_posttypes = __('eesy-posttype_posttypes-headline', 'eesy-posttype');
    $text_taxonomies = __('eesy-posttype_taxonomies-headline', 'eesy-posttype');
    $text_options = __('eesy-posttype_options-headline', 'eesy-posttype');

    add_menu_page('eesy Posttype', 'eesy Posttype', 'manage_options', 'eesy_posttype', 'eesy_posttype', 'dashicons-pressthis', 6);
    add_submenu_page('eesy_posttype', $text_posttypes, $text_posttypes, 'manage_options', 'eesy_posttype_posttypes', 'eesy_posttype_posttypes');
    add_submenu_page('eesy_posttype', $text_taxonomies, $text_taxonomies, 'manage_options', 'eesy_posttype_taxonomies', 'eesy_posttype_taxonomies');
    add_submenu_page('eesy_posttype', $text_options, $text_options, 'manage_options', 'eesy_posttype_options', 'eesy_posttype_options');
    add_submenu_page('eesy_posttype', 'FAQ', 'FAQ', 'manage_options', 'eesy_posttype_faq', 'eesy_posttype_faq');
}

function eesy_posttype() {
    include 'tpl/eesy_posttype_dashboard.php';
}

function eesy_posttype_posttypes() {
    include 'tpl/eesy_posttype_posttypes.php';
}

function eesy_posttype_taxonomies() {
    include 'tpl/eesy_posttype_taxonomies.php';
}

function eesy_posttype_options() {
    include 'tpl/eesy_posttype_options.php';
}

function eesy_posttype_faq() {
    include 'tpl/eesy_posttype_faq.php';
}
// add posttype to admin menu END


// insert postypes START
add_action('admin_post_insert_eesy_post_type', 'insert_eesy_post_type');

function insert_eesy_post_type() {
    if (check_post_type_name(strtolower($_POST['eesy_post_type_name'])) == 1 && check_post_type_slug(strtolower($_POST['eesy_post_type_arg_slug'])) == 1 && check_post_type_menu_name(strtolower($_POST['eesy_post_type_menu_name'])) == 1) {

        if (get_option('eesy_post_types')) {
            $optarray = unserialize(get_option('eesy_post_types'));
        } else {
            $optarray = array();
        }

        if (isset($_POST))
            unset($_POST['action']);

        $optarray[] = $_POST;
        update_option('eesy_post_types', serialize($optarray));
        wp_redirect(get_bloginfo('url') . '/wp-admin/admin.php?page=eesy_posttype_posttypes&msg=1');
    } else {
        $errorcode = '';
        if (check_post_type_name(strtolower($_POST['eesy_post_type_name'])) != 1) {
            $errorcode = 2;
        } elseif (check_post_type_slug(strtolower($_POST['eesy_post_type_arg_slug'])) != 1) {
            $errorcode = 3;
        } elseif (check_post_type_slug(strtolower($_POST['eesy_post_type_menu_name'])) != 1) {
            $errorcode = 4;
        }
        $getter = '';
        unset($_POST['action']);
        unset($_POST['update_eesy_post_type_id']);
        foreach ($_POST as $key_post => $value_post) {
            $getter .= '&' . $key_post . '=' . $value_post;
        }
        wp_redirect(get_bloginfo('url') . '/wp-admin/admin.php?page=eesy_posttype_posttypes&msg=' . $errorcode . $getter);
    }
    die(__FUNCTION__);
}

function check_post_type_name($posttype_name) {
    if (get_option('eesy_post_types') && !empty(get_option('eesy_post_types'))) {
        $eesy_post_types = unserialize(get_option('eesy_post_types'));
        $check_number = 0;
        foreach ($eesy_post_types as $key => $value) {

            if ($posttype_name == strtolower($value['eesy_post_type_name'])) {
                $check_number = 2;
            }
        }
        if ($check_number == 2) {
            return 2;
        } else {
            return 1;
        }
    } else {
        return 1;
    }
}

function check_post_type_slug($posttype_name) {
    if (get_option('eesy_post_types') && !empty(get_option('eesy_post_types'))) {
        $eesy_post_types = unserialize(get_option('eesy_post_types'));
        $check_number = 0;
        foreach ($eesy_post_types as $key => $value) {

            if ($posttype_name == strtolower($value['eesy_post_type_arg_slug'])) {
                $check_number = 2;
            }
        }
        if ($check_number == 2) {
            return 2;
        } else {
            return 1;
        }
    } else {
        return 1;
    }
}

function check_post_type_menu_name($posttype_name) {
    if (get_option('eesy_post_types') && !empty(get_option('eesy_post_types'))) {
        $eesy_post_types = unserialize(get_option('eesy_post_types'));
        $check_number = 0;
        foreach ($eesy_post_types as $key => $value) {

            if ($posttype_name == strtolower($value['eesy_post_type_menu_name'])) {
                $check_number = 2;
            }
        }
        if ($check_number == 2) {
            return 2;
        } else {
            return 1;
        }
    } else {
        return 1;
    }
}
// insert postypes END


// create postypes START
add_action('init', 'make_eesy_post_types');

function make_eesy_post_types() {
    if (get_option('eesy_post_types') && !empty(get_option('eesy_post_types'))) {
        $eesy_post_types = unserialize(get_option('eesy_post_types'));

        $catarray = array();

        foreach ($eesy_post_types as $value) {
            $catarray[] = eesy_special_chars_rewrite($value['eesy_post_type_name']);
        }

        foreach ($eesy_post_types as $key => $value) {

            if ($value['eesy_post_type_arg_public'] == 'true') {
                $public = true;
            } else {
                $public = false;
            }

            if ($value['eesy_post_type_arg_show_adminbar'] == 'true') {
                $show_in_admin_bar = true;
            } else {
                $show_in_admin_bar = false;
            }

            register_post_type(eesy_special_chars_rewrite($value['eesy_post_type_name']), array(
                'labels' => array(
                    'name' => $value['eesy_post_type_name'],
                    'singular_name' => $value['eesy_post_type_menu_singular_name'],
                    'menu_name' => $value['eesy_post_type_menu_name'],
                    'name_admin_bar' => $value['eesy_post_type_menu_name'],
                    'add_new' => 'Hinzufügen',
                    'add_new_item' => 'Neuen ' . $value['eesy_post_type_menu_singular_name'] . ' erstellen',
                    'new_item' => 'Neuen ' . $value['eesy_post_type_menu_singular_name'] . ' erstellen',
                    'edit_item' => $value['eesy_post_type_menu_singular_name'] . 'bearbeiten',
                    'view_item' => $value['eesy_post_type_menu_singular_name'] . ' Anschauen',
                    'all_items' => 'Alle ' . $value['eesy_post_type_menu_plural_name'],
                    'search_items' => 'Durchsuchen',
                    'parent_item_colon' => 'Elternpost',
                    'not_found' => 'Keine ' . $value['eesy_post_type_menu_plural_name'] . ' gefunden',
                    'not_found_in_trash' => 'Keine ' . $value['eesy_post_type_menu_plural_name'] . ' im Papierkorb gefunden',
                ),
                'public' => true,
                'publicly_queryable' => true,
                'show_ui' => true,
                'show_in_menu' => true,
                'show_in_nav_menus' => true,
                'show_in_admin_bar' => true,
                'query_var' => true,
                'rewrite' => array('slug' => eesy_special_chars_rewrite($value['eesy_post_type_arg_slug'])),
                'capability_type' => 'post',
                'has_archive' => true,
                'hierarchical' => true,
                'menu_position' => null,
                'supports' => array('title', 'editor', 'author', 'thumbnail', 'excerpt', 'comments')
                )
            );
        }

        $labels = array(
            'name' => 'Kategorien',
            'singular_name' => 'Kategorie',
            'search_items' => 'Kategorien durchsuchen',
            'all_items' => 'Alle Kategorien',
            'parent_item' => 'Elternkategorie',
            'edit_item' => 'Kategorie bearbeiten',
            'update_item' => 'Kategorie ändern',
            'add_new_item' => 'Kategorie hinzufügen',
            'new_item_name' => 'Neue Kategorie Name',
            'menu_name' => 'Kategorien',
        );

        $args = array(
            'hierarchical' => true,
            'labels' => $labels,
            'show_ui' => true,
            'show_admin_column' => true,
            'query_var' => true,
            'rewrite' => array('slug' => $value['eesy_post_type_name'] . '_category'),
        );

        register_taxonomy(eesy_special_chars_rewrite($value['eesy_post_type_name']) . '_category', $catarray, $args);

        create_eesy_taxonomies();
        flush_rewrite_rules();
    }
}
// create postypes END


// create taxonomies START
function create_eesy_taxonomies() {
    $eesy_custom_taxonomies_array = array();
    $eesy_custom_taxonomies = unserialize(get_option('eesy_custom_taxonomies'));
    if (get_option('eesy_custom_taxonomies') && !empty(get_option('eesy_custom_taxonomies'))) {
        foreach ($eesy_custom_taxonomies as $key => $value) {
            if (array_key_exists($value['taxlabel']['eesy-posttype_taxonomies-name'], $eesy_custom_taxonomies_array)) {
                $eesy_custom_taxonomies_array[$value['eesy-posttype_attributes-associate-posttype'] . '_' . $value['taxlabel']['eesy-posttype_taxonomies-name']] = $value;
                $eesy_custom_taxonomies_array[$value['eesy-posttype_attributes-associate-posttype'] . '_' . $value['taxlabel']['eesy-posttype_taxonomies-name']]['rewrite'] = $value['eesy-posttype_attributes-associate-posttype'] . '_' . $value['taxlabel']['eesy-posttype_taxonomies-slug'];
                $eesy_custom_taxonomies_array[$value['eesy-posttype_attributes-associate-posttype'] . '_' . $value['taxlabel']['eesy-posttype_taxonomies-name']]['endname'] = $value['eesy-posttype_attributes-associate-posttype'] . '_' . $value['taxlabel']['eesy-posttype_taxonomies-name'];
            } else {
                $eesy_custom_taxonomies_array[$value['taxlabel']['eesy-posttype_taxonomies-name']] = $value;
                $eesy_custom_taxonomies_array[$value['taxlabel']['eesy-posttype_taxonomies-name']]['rewrite'] = $value['taxlabel']['eesy-posttype_taxonomies-slug'];
                $eesy_custom_taxonomies_array[$value['taxlabel']['eesy-posttype_taxonomies-name']]['endname'] = $value['taxlabel']['eesy-posttype_taxonomies-name'];
            }
        }
    }
    if (get_option('eesy_custom_taxonomies') && !empty(get_option('eesy_custom_taxonomies'))) {
        if (isset($eesy_custom_taxonomies_array) && count($eesy_custom_taxonomies_array) != 0) {

            foreach ($eesy_custom_taxonomies_array as $key_eesy_taxonomie => $value_eesy_taxonomie) {

                $labels = array(
                    'name' => $value_eesy_taxonomie['taxlabel']['eesy-posttype_taxonomies-name'],
                    'singular_name' => $value_eesy_taxonomie['taxlabel']['eesy-posttype_taxonomies-name'],
                    'search_items' => $value_eesy_taxonomie['taxlabel']['eesy-posttype_taxonomies-name'] . ' durchsuchen',
                    'edit_item' => $value_eesy_taxonomie['taxlabel']['eesy-posttype_taxonomies-name'] . ' bearbeiten',
                    'update_item' => $value_eesy_taxonomie['taxlabel']['eesy-posttype_taxonomies-name'] . ' updaten', // not found in WP
                    'add_new_item' => $value_eesy_taxonomie['taxlabel']['eesy-posttype_taxonomies-name'] . ' hinzufügen',
                    'not_found' => 'kein ' . $value_eesy_taxonomie['taxlabel']['eesy-posttype_taxonomies-name'] . ' gefunden',
                    'menu_name' => $value_eesy_taxonomie['taxlabel']['eesy-posttype_taxonomies-name'],
                );

                $args = array(
                    'hierarchical' => true,
                    'labels' => $labels,
                    'show_ui' => true,
                    'show_admin_column' => true,
                    'update_count_callback' => '_update_post_term_count',
                    'query_var' => true,
                    'rewrite' => array('slug' => eesy_special_chars_rewrite($value_eesy_taxonomie['rewrite'])),
                );

                register_taxonomy(strtolower($value_eesy_taxonomie['endname']), strtolower(eesy_special_chars_rewrite($value_eesy_taxonomie['eesy-posttype_attributes-associate-posttype'])), $args);
            }
        }
    }
}

add_action('admin_post_insert_eesy_taxonomie', 'insert_eesy_taxonomie');

function insert_eesy_taxonomie() {
    $tax_check = eesy_taxonomie_check($_POST['taxlabel']['eesy-posttype_taxonomies-name'], $_POST['eesy-posttype_attributes-associate-posttype'], $_POST['taxlabel']['eesy-posttype_taxonomies-slug']);

    if ($tax_check == 1) {
        $ref = '/wp-admin/admin.php?page=eesy_posttype_taxonomies&msg=1';
        unset($_POST['_wp_http_referer']);
        unset($_POST['insert_taxonomie_nonce']);
        unset($_POST['action']);
        unset($_POST['update_eesy_taxonomie_id']);
        if (get_option('eesy_custom_taxonomies')) {
            $eesy_taxes = unserialize(get_option('eesy_custom_taxonomies'));
            $eesy_taxes[] = $_POST;
        } else {
            $eesy_taxes = array();
            $eesy_taxes[] = $_POST;
        }
        update_option('eesy_custom_taxonomies', serialize($eesy_taxes));
    } elseif ($tax_check == 2) {
        $getter = '';
        unset($_POST['action']);
        unset($_POST['update_eesy_taxonomie_id']);
        foreach ($_POST['taxlabel'] as $key_post => $value_post) {
            $getter .= '&' . $key_post . '=' . $value_post;
        }
        unset($_POST['taxlabel']);
        foreach ($_POST as $key_post => $value_post) {
            $getter .= '&' . $key_post . '=' . $value_post;
        }
        $ref = '/wp-admin/admin.php?page=eesy_posttype_taxonomies&msg=2' . $getter;
    } elseif ($tax_check == 3) {
        $getter = '';
        unset($_POST['action']);
        unset($_POST['update_eesy_taxonomie_id']);
        foreach ($_POST['taxlabel'] as $key_post => $value_post) {
            $getter .= '&' . $key_post . '=' . $value_post;
        }
        unset($_POST['taxlabel']);

        foreach ($_POST as $key_post => $value_post) {
            $getter .= '&' . $key_post . '=' . $value_post;
        }

        $ref = '/wp-admin/admin.php?page=eesy_posttype_taxonomies&msg=3' . $getter;
    }
    wp_redirect(get_bloginfo('url') . $ref);
    exit();
}

function strToBool($str) {
    return ($str === 'true' || $str === '1' ? true : false);
}

function eesy_taxonomie_check($taxname, $post_type_name, $tax_slug) {
    $checknumber = 1;
    $eesy_taxes = unserialize(get_option('eesy_custom_taxonomies'));
    if (!empty($eesy_taxes)) {
        foreach ($eesy_taxes as $key => $value) {
            if (strtolower($value['taxlabel']['eesy-posttype_taxonomies-name']) == strtolower($taxname) && strtolower($post_type_name) == strtolower($value['eesy-posttype_attributes-associate-posttype'])) {
                $checknumber = 2;
            } elseif (strtolower($tax_slug) == strtolower($value['taxlabel']['eesy-posttype_taxonomies-slug']) && strtolower($post_type_name) == strtolower($value['eesy-posttype_attributes-associate-posttype'])) {
                $checknumber = 3;
            }
        }
    }
    return $checknumber;
}
// create taxonomies END


// delete posttype START
add_action("wp_ajax_nopriv_eesy_posttype_delete", "eesy_posttype_delete");
add_action("wp_ajax_eesy_posttype_delete", "eesy_posttype_delete");

function eesy_posttype_delete() {
    $eesy_custom_post_types = unserialize(get_option('eesy_post_types'));
    //eesy_posttype_delete_posts($eesy_custom_post_types[$_REQUEST['pid']]['eesy_post_type_name']);
    eesy_posttype_delete_taxonomies($eesy_custom_post_types[$_REQUEST['pid']]['eesy_post_type_name']);
    unset($eesy_custom_post_types[$_REQUEST['pid']]);
    $eesy_post_types = array_values($eesy_custom_post_types);
    update_option('eesy_post_types', serialize($eesy_post_types));
    wp_die();
}

function eesy_posttype_delete_posts($posttype) {
    $args = array('post_type' => $posttype);
    $posts = get_posts($args);
    foreach ($posts as $post) {
        wp_delete_post($post->ID, true);
    }
}

function eesy_posttype_delete_taxonomies($posttype) {
    $eesy_taxonomies = get_object_taxonomies($posttype);
    $all_taxonomies = unserialize(get_option('eesy_custom_taxonomies'));
    foreach ($eesy_taxonomies as $key => $value) {
        $terms = get_terms(array(
            'taxonomy' => $value,
            'hide_empty' => false,
        ));
        foreach ($terms as $key_term => $value_term) {
            wp_delete_term($value_term->term_id, $value);
        }
    }
    foreach ($all_taxonomies as $key_all_eesy_taxonomies => $value_all_eesy_taxonomies) {
        if ($posttype == $value_all_eesy_taxonomies['eesy-posttype_attributes-associate-posttype']) {
            unset($all_taxonomies[$key_all_eesy_taxonomies]);
        }
        $eesy_custom_taxonomies = array_values($all_taxonomies);
        update_option('eesy_custom_taxonomies', serialize($eesy_custom_taxonomies));
    }
}
// delete posttype END


// edit posttype START
add_action("wp_ajax_nopriv_eesy_posttype_edit", "eesy_posttype_edit");
add_action("wp_ajax_eesy_posttype_edit", "eesy_posttype_edit");

function eesy_posttype_edit() {
    $eesy_custom_post_types = unserialize(get_option('eesy_post_types'));
    echo json_encode($eesy_custom_post_types[$_GET['pid']]);
    wp_die();
}

add_action('admin_post_update_eesy_post_type', 'update_eesy_post_type');

function update_eesy_post_type() {
    $post_type_id = $_POST['update_eesy_post_type_id'];

    if (check_post_type_name_update(strtolower($_POST['eesy_post_type_name']), $post_type_id) == 1) {
        unset($_POST['update_eesy_post_type_id']);
        unset($_POST['action']);
        $eesy_custom_post_types = unserialize(get_option('eesy_post_types'));
        $eesy_custom_post_types[$post_type_id] = $_POST;
        update_option('eesy_post_types', serialize($eesy_custom_post_types));
        wp_redirect(get_bloginfo('url') . '/wp-admin/admin.php?page=eesy_posttype_posttypes&msg=1');
    } else {
        $getter = '';
        unset($_POST['action']);
        unset($_POST['update_eesy_post_type_id']);
        foreach ($_POST as $key_post => $value_post) {
            $getter .= '&' . $key_post . '=' . $value_post;
        }
        wp_redirect(get_bloginfo('url') . '/wp-admin/admin.php?page=eesy_posttype_posttypes&msg=2' . $getter);
    }

    die(__FUNCTION__);
}

function check_post_type_name_update($posttype_name, $post_type_id) {
    if (get_option('eesy_post_types') && !empty(get_option('eesy_post_types'))) {
        $eesy_post_types = unserialize(get_option('eesy_post_types'));
        $check_number = 0;
        unset($eesy_post_types[$post_type_id]);

        foreach ($eesy_post_types as $key => $value) {

            if ($posttype_name == strtolower($value['eesy_post_type_name'])) {
                $check_number = 2;
            }
        }
        if ($check_number == 2) {
            return 2;
        } else {
            return 1;
        }
    } else {
        return 1;
    }
}
// edit posttype END


// delete taxonomy START
add_action("wp_ajax_nopriv_eesy_delete_taxonomie_now", "eesy_delete_taxonomie_now");
add_action("wp_ajax_eesy_delete_taxonomie_now", "eesy_delete_taxonomie_now");

function eesy_delete_taxonomie_now() {
    $eesy_custom_taxonomies = unserialize(get_option('eesy_custom_taxonomies'));
    unset($eesy_custom_taxonomies[$_GET['pid']]);
    $eesy_custom_taxonomies = array_values($eesy_custom_taxonomies);
    update_option('eesy_custom_taxonomies', serialize($eesy_custom_taxonomies));
    wp_die();
}
// delete taxonomy END


// edit taxonomy START
add_action("wp_ajax_nopriv_eesy_taxonomie_edit", "eesy_taxonomie_edit");
add_action("wp_ajax_eesy_taxonomie_edit", "eesy_taxonomie_edit");

function eesy_taxonomie_edit() {
    $eesy_custom_post_types = unserialize(get_option('eesy_custom_taxonomies'));
    echo json_encode($eesy_custom_post_types[$_GET['pid']]);
    wp_die();
}

add_action('admin_post_eesy_taxonomie_update', 'eesy_taxonomie_update');

function eesy_taxonomie_update() {
    $tax_check = eesy_taxonomie_check_update($_POST['taxlabel']['eesy-posttype_taxonomies-name'], $_POST['eesy-posttype_attributes-associate-posttype'], $_POST['taxlabel']['eesy-posttype_taxonomies-slug'], $_POST['update_eesy_taxonomie_id']);

    if ($tax_check == 1) {
        $backlink = '/wp-admin/admin.php?page=eesy_posttype_taxonomies&msg=1';
        $update_id = $_POST['update_eesy_taxonomie_id'];
        unset($_POST['action']);
        unset($_POST['_wp_http_referer']);
        unset($_POST['update_eesy_taxonomie_id']);
        $eesy_custom_post_types = unserialize(get_option('eesy_custom_taxonomies'));
        $eesy_custom_post_types[$update_id] = $_POST;
        update_option('eesy_custom_taxonomies', serialize($eesy_custom_post_types));
    } elseif ($tax_check == 2) {
        $getter = '';
        foreach ($_POST['taxlabel'] as $key_post => $value_post) {
            $getter .= '&' . $key_post . '=' . $value_post;
        }
        unset($_POST['taxlabel']);

        foreach ($_POST as $key_post => $value_post) {
            $getter .= '&' . $key_post . '=' . $value_post;
        }
        $backlink = '/wp-admin/admin.php?page=eesy_posttype_taxonomies&msg=2' . $getter;
    } elseif ($tax_check == 3) {
        $backlink = '/wp-admin/admin.php?page=eesy_posttype_taxonomies&msg=3' . $getter;
    }
    wp_redirect(get_bloginfo('url') . $backlink);
    exit();
}

function eesy_taxonomie_check_update($taxname, $post_type_name, $tax_slug, $tax_id) {

    $checknumber = 1;
    $eesy_taxes = unserialize(get_option('eesy_custom_taxonomies'));
    unset($eesy_taxes[$tax_id]);

    if (!empty($eesy_taxes)) {
        foreach ($eesy_taxes as $key => $value) {
            if (strtolower($value['taxlabel']['eesy-posttype_taxonomies-name']) == strtolower($taxname) && strtolower($post_type_name) == strtolower($value['eesy-posttype_attributes-associate-posttype'])) {
                $checknumber = 2;
            } elseif (strtolower($tax_slug) == strtolower($value['taxlabel']['eesy-posttype_taxonomies-slug']) && strtolower($post_type_name) == strtolower($value['eesy-posttype_attributes-associate-posttype'])) {
                $checknumber = 3;
            }
        }
    }
    return $checknumber;
}
// edit taxonomy END


// edit options START
add_action('admin_post_insert_eesy_options', 'insert_eesy_options');

function insert_eesy_options() {
    unset($_POST['action']);
    update_option('eesy_plugin_options', serialize($_POST));
    wp_redirect(get_bloginfo('url') . '/wp-admin/admin.php?page=eesy_posttype_options&msg=1');
    exit();
}
// edit options END


// replace all special chars START
function eesy_special_chars_rewrite($string) {

    return sanitize_title($string);
}
// replace all special chars END
